@@ -3,10 +3,9 @@ from collections import OrderedDict
 from contextlib import contextmanager
 import inspect
 import json
-from os.path import splitext
+import os
 import re
 from typing import List
-from urllib.parse import urlparse
 
 import yaml
 
@@ -35,6 +34,7 @@ from myst_parser.mocking import (
 )
 from .parse_directives import parse_directive_text, DirectiveParsingError
 from .parse_html import HTMLImgParser
+from .utils import is_external_url
 
 
 def make_document(source_path="notset") -> nodes.document:
@@ -48,6 +48,7 @@ REGEX_ADMONTION = re.compile(
     r"\{(?P<name>[a-zA-Z]+)(?P<classes>(?:\,-?[_a-zA-Z]+[_a-zA-Z0-9-]*)*)\}(?P<title>.*)"  # noqa: E501
 )
 STD_ADMONITIONS = {
+    "admonition": nodes.admonition,
     "attention": nodes.attention,
     "caution": nodes.caution,
     "danger": nodes.danger,
@@ -436,40 +437,32 @@ class DocutilsRenderer:
 
         ref_node = nodes.reference()
         self.add_line_and_source_path(ref_node, token)
-        # Check destination is supported for cross-linking and remove extension
-        # TODO escape urls?
-        destination = token.attrGet("href")
-        title = token.attrGet("title")
-        _, ext = splitext(destination)
-        # TODO check for other supported extensions, such as those specified in
-        # the Sphinx conf.py file but how to access this information?
-        # TODO this should probably only remove the extension for local paths,
-        # i.e. not uri's starting with http or other external prefix.
+        destination = token.attrGet("href")  # escape urls?
+
+        if self.config.get(
+            "relative-docs", None
+        ) is not None and destination.startswith(self.config["relative-docs"][0]):
+            # make the path relative to an "including" document
+            source_dir, include_dir = self.config["relative-docs"][1:]
+            destination = os.path.relpath(
+                os.path.join(include_dir, os.path.normpath(destination)), source_dir
+            )
 
-        # if ext.replace('.', '') in self.supported:
-        #     destination = destination.replace(ext, '')
         ref_node["refuri"] = destination
 
+        title = token.attrGet("title")
         if title:
             ref_node["title"] = title
         next_node = ref_node
 
-        url_check = urlparse(destination)
-        # If there's not a url scheme (e.g. 'https' for 'https:...' links),
-        # or there is a scheme but it's not in the list of known_url_schemes,
-        # then assume it's a cross-reference
-        known_url_schemes = self.config.get("myst_url_schemes", None)
-        if known_url_schemes:
-            scheme_known = url_check.scheme in known_url_schemes
-        else:
-            scheme_known = bool(url_check.scheme)
-
-        if not url_check.fragment and not scheme_known:
-            self.handle_cross_reference(token, destination)
-        else:
+        if is_external_url(
+            destination, self.config.get("myst_url_schemes", None), True
+        ):
             self.current_node.append(next_node)
             with self.current_node_context(ref_node):
                 self.render_children(token)
+        else:
+            self.handle_cross_reference(token, destination)
 
     def handle_cross_reference(self, token, destination):
         if not self.config.get("ignore_missing_refs", False):
@@ -499,9 +492,20 @@ class DocutilsRenderer:
     def render_image(self, token):
         img_node = nodes.image()
         self.add_line_and_source_path(img_node, token)
-        img_node["uri"] = token.attrGet("src")
-        # TODO ideally we would render proper markup here,
-        # this probably requires an upstream change in sphinx
+        destination = token.attrGet("src")
+
+        if self.config.get("relative-images", None) is not None and not is_external_url(
+            destination, None, True
+        ):
+            # make the path relative to an "including" document
+            destination = os.path.normpath(
+                os.path.join(
+                    self.config.get("relative-images"), os.path.normpath(destination)
+                )
+            )
+
+        img_node["uri"] = destination
+
         img_node["alt"] = self.renderInlineAsText(token.children)
         title = token.attrGet("title")
         if title:
@@ -672,8 +676,93 @@ class DocutilsRenderer:
             problematic = inliner.problematic(text, rawsource, message)
             self.current_node += problematic
 
-    def get_admonition(self, token, name, classes, title):
+    def render_container_myst_open(self, token):
+        """Render a container (`:::{name}` blocks), based on its name."""
+        # match first line regex
+        match = REGEX_ADMONTION.match(token.info.strip())
 
+        # default behaviour
+        if not match:
+            return self.default_container(
+                token, "admonition argument did not match required regex"
+            )
+
+        name = match.groupdict()["name"]
+
+        if name in STD_ADMONITIONS:
+            admonition = self.get_admonition(token, **match.groupdict())
+            self.add_line_and_source_path(admonition, token)
+            with self.current_node_context(admonition, append=True):
+                self.render_children(token)
+            return
+
+        if name == "figure" and self.config.get("enable_figures", False):
+            # must be of length 2
+            if not len(token.children) == 2:
+                return self.figure_error(token)
+            # 1st must be paragraph_open with 1 child type inline and 1 child type image
+            html_image = None
+            if token.children[0].type == "html_block":
+                html_image = HTMLImgParser().parse(
+                    token.children[0].content, self.document, token.children[0].map[0]
+                )
+                if html_image is None:
+                    return self.figure_error(token)
+            elif not (
+                token.children[0].children
+                and len(token.children[0].children) == 1
+                and len(token.children[0].children[0].children) == 1
+                and token.children[0].children[0].children[0].type == "image"
+            ):
+                return self.figure_error(token)
+            # 2nd must be a paragraph
+            if not token.children[1].type == "paragraph_open":
+                return self.figure_error(token)
+
+            figure_node = nodes.figure(
+                "", classes=match.groupdict()["classes"][1:].split(",")
+            )
+            if match.groupdict()["title"].strip():
+                name = nodes.fully_normalize_name(match.groupdict()["title"].strip())
+                figure_node["names"].append(name)
+                self.document.note_explicit_target(figure_node, figure_node)
+            with self.current_node_context(figure_node, append=True):
+                if html_image is None:
+                    self.render_image(token.children[0].children[0].children[0])
+                else:
+                    self.current_node.append(html_image)
+                caption = nodes.caption("", "")
+                with self.current_node_context(caption, append=True):
+                    self.render_children(token.children[1])
+            return
+
+        return self.default_container(token, f"admonition name not recognised: {name}")
+
+    def default_container(self, token, message):
+        """Report a warning and use the default note admonition."""
+        self.current_node.append(
+            self.reporter.warning(
+                f"{message}, defaulting to note: {token.info}",
+                line=token.map[0],
+            )
+        )
+        admonition = nodes.note("")
+        self.add_line_and_source_path(admonition, token)
+        with self.current_node_context(admonition, append=True):
+            self.render_children(token)
+
+    def figure_error(self, token):
+        """A warning for reporting an invalid figure."""
+        self.current_node.append(
+            self.reporter.warning(
+                "Figure container should have exactly an image,"
+                " followed by single paragraph",
+                line=token.map[0],
+            )
+        )
+
+    def get_admonition(self, token, name, classes, title):
+        """Create an admonition node. """
         line = token.map[0]
 
         if name == "admonition":
@@ -688,34 +777,9 @@ class DocutilsRenderer:
             node += messages
             return node
 
-        node_cls = STD_ADMONITIONS.get(name, None)
-        if node_cls is None:
-            self.current_node.append(
-                self.reporter.warning(
-                    f"admonition name not recognised, defaulting to note: {name}",
-                    line=line,
-                )
-            )
-            node_cls = nodes.note
+        node_cls = STD_ADMONITIONS.get(name)
         return node_cls(title, classes=classes[1:].split(","))
 
-    def render_container_admonition_open(self, token):
-        match = REGEX_ADMONTION.match(token.info.strip())
-        if not match:
-            self.current_node.append(
-                self.reporter.warning(
-                    "admonition argument did not match required regex, "
-                    f"defaulting to note: {token.info}",
-                    line=token.map[0],
-                )
-            )
-            admonition = nodes.note("")
-        else:
-            admonition = self.get_admonition(token, **match.groupdict())
-        self.add_line_and_source_path(admonition, token)
-        with self.current_node_context(admonition, append=True):
-            self.render_children(token)
-
     def render_dl_open(self, token):
         """Render a definition list."""
         node = nodes.definition_list(classes=["simple", "myst"])
@@ -781,6 +845,12 @@ class DocutilsRenderer:
             self.current_node += [error] + messages
             return
 
+        if issubclass(directive_class, Include):
+            # this is a Markdown only option,
+            # to allow for altering relative image reference links
+            directive_class.option_spec["relative-images"] = directives.flag
+            directive_class.option_spec["relative-docs"] = directives.path
+
         try:
             arguments, options, body_lines = parse_directive_text(
                 directive_class, arguments, content
